@@ -1,56 +1,34 @@
 package RPSL::Parser;
-require 5.006_001;
 use strict;
 use warnings;
-use base qw( Class::Accessor );
-__PACKAGE__->mk_accessors(
-    qw( text type tokens key comment
-      object omit_key order )
-);
+use base qw( Object::Accessor );
 
-our $VERSION = "0.04000";
 
-# Public Interface Methods
+our $VERSION = do { q$Revision: 19 $ =~ m{(\d+)}; return $1 / 100 };
+
+BEGIN { $Object::Accessor::FATAL = 1; }
 
-# Constructor
 sub new {
     my $class = shift;
-    my $self  = bless {
-        __META => {
-            comment => {},
-            object  => {},
-        }
-    }, $class;
+
+    # I need to initialize some variables before use
+    my %accessors = (
+        comment  => {},
+        object   => {},
+        omit_key => [],
+        order    => [],
+    );
+    my $self = $class->SUPER::new;
+    $self->mk_accessors( qw(key text tokens type), keys %accessors );
+    $self->$_( $accessors{$_} ) for keys %accessors;
     return $self;
 }
 
-# service method
 sub parse {
-    my $self_or_class = shift;
-    my $self = ref $self_or_class ? $self_or_class : $self_or_class->new();
-    unless ( UNIVERSAL::isa( $self, q{RPSL::Parser} ) ) {
-        $self = RPSL::Parser->new;
-    }
+    my $self = shift;
     return $self->_read_text(@_)->_tokenize->_build_parse_tree->_parse_tree;
 }
 
-# Private Interface Methods
-
-# Overriding Class::Accessor::get
-sub get {
-    my ( $self, @keys ) = @_;
-    return wantarray
-      ? @{ $self->{__META} }{@keys}
-      : ${ $self->{__META} }{ $keys[0] };
-}
-
-# Overriding Class::Accessor::set
-sub set {
-    my ( $self, $key, $value ) = @_;
-    return $self->{__META}{$key} = $value;
-}
-
-# Other private methods
 sub _read_text {
     my ( $self, @input ) = @_;
     my $data;
@@ -81,14 +59,14 @@ sub _tokenize {
     study $text;
     my @tokens = $text =~ m{
         ^(?:
-            # Look for an attribute name ...
+	    # Look for an attribute name ...
             ( [a-z0-9][a-z0-9_-]+[a-z0-9] ):
-            # ... followed by zero or more horizontal spaces ...
+	    # ... followed by zero or more horizontal spaces ...
             [\t ]*
-            # ... followed by a value ...
+	    # ... followed by a value ...
             ( .*?
-                # ... and all valid continuation lines.
-                (?: \n [\s+] .* ? )*
+		# ... and all valid continuation lines.
+	        (?: \n [\s+] .* ? )*
             )
         )$
     }mixg;
@@ -154,7 +132,7 @@ sub _build_parse_tree {
     # Stores the object primary key value
     my $primary_key = $self->object->{ $order[0] };
     $primary_key = $primary_key->[0]
-      if UNIVERSAL::isa( $primary_key, 'ARRAY' );
+        if UNIVERSAL::isa( $primary_key, 'ARRAY' );
     $primary_key =~ s{\s*\#.*$}{};
     $self->key($primary_key);
 
@@ -165,14 +143,12 @@ sub _build_parse_tree {
 sub _parse_tree {
     my $self = shift;
     return {
-        data => $self->object,
-        type => $self->type,
-        key  => $self->key,
-        meta => {
-            order    => $self->order,
-            comment  => $self->comment,
-            omit_key => $self->omit_key,
-        },
+        data     => $self->object,
+        order    => $self->order,
+        type     => $self->type,
+        key      => $self->key,
+        comment  => $self->comment,
+        omit_key => $self->omit_key,
     };
 }
 
@@ -185,19 +161,11 @@ RPSL::Parser - Router Policy Specification Language (RFC2622) Parser
 
 =head1 SYNOPSIS
 
-    # The new interface doesn't requires the creation of
-    # a parser object anymore:
-    use RPSL::Parser;
-    my $data_structure = RPSL::Parser->parse( $data );
-
-    ###########
-
-    # Alternativelly, use the old and deprecated interface:
-    use RPSL::Parser;
-    # Create a parser
-    my $parser = new RPSL::Parser;
-    # Use it
-    my $data_structure = $parser->parse($data);
+	use RPSL::Parser;
+	# Create a parser
+	my $parser = new RPSL::Parser;
+	# Use it
+	my $data_structure = $parser->parse($data);
 
 =head1 DESCRIPTION
 
@@ -210,14 +178,10 @@ I<RPSL> namespace for validation and more RFC2622 related functionality).
 
 =head1 PUBLIC METHODS
 
-=head2 B<C<new()>> B<deprecated>
+=head2 B<C<new()>>
 
 Constructor. Handles the accessor creation and returns a new L<RPSL::Parser> object.
 
-This method is deprecated, under request of some users. The RPSL::Parser
-interface will change, and there will be no need to create a "parser" object
-anymore.
-
 =head2 B<C<parse( [ $rpsl_source | IO::Handle | GLOB ] )>>
 
 Parses B<one> RPSL object for each call, uses the parser internal fields to
@@ -228,11 +192,6 @@ It accepts a list or a scalar containing the strings representing the RPSL
 source code you want to parse, and can read it directly from any L<IO::Handle>
 or C<GLOB> representing an open file handle.
 
-This is a mixture between a class and a object method at this moment, due to
-the deprecation of the C<new()> method. It can detect whenever it was called
-with a class as the first parameter, and will try to instantiate and use that
-class as the parser implementation.
-
 =head1 ACCESSOR METHODS
 
 =head2 B<C<comment()>>
@@ -273,9 +232,9 @@ produced by the tokenize method.
 
 Stores a string representing the name of the first RPSL attribute found in the
 RPSL text parsed. The RFC 2622 requires that the first attribute declares the
-"data type" of the RPSL object declared.
+"data type" of the RPSL object declared. 
 
-=head1 Private Interface
+=head1 Private Interface 
 
 =head2 B<C<_read_text( @input )>>
 
@@ -345,7 +304,7 @@ the different RPSL object types by other RPSL namespace modules.
 =head2 B<key>
 
 Holds the value contained by the first attribute of an RPSL object. This is
-sometimes the "primary key" of a RPSL object, but not always.
+sometimes the "primary key" of a RPSL object, but not always. 
 
 =head2 B<comment>
 
@@ -377,18 +336,18 @@ like the one below. It's a simple query and I will not explain how you could do
 it here, because it's a bit out of scope for this module. Anyway, you have the
 following text as a result:
 
-    person:       I. M. A. Fool
-    address:      F.A.K.E Corporation
-    address:      226 Nowhere st
-    address:      10DD10 Nevercity
-                  Neverland
-    phone:        +99-99-999-9999
-    fax-no:       +99-99-999-9999
-    e-mail:       xxx@somewhere.com
-    nic-hdl:      XXX007-RIPE # Look, ma, I'm 007! ;)
-    mnt-by:       NICE-GUY-MNT
-    changed:      xxx@somewhere.com 20001016
-    source:       RIPE
+	person:       I. M. A. Fool
+	address:      F.A.K.E Corporation
+	address:      226 Nowhere st
+	address:      10DD10 Nevercity
+		      Neverland
+	phone:        +99-99-999-9999
+	fax-no:       +99-99-999-9999
+	e-mail:       xxx@somewhere.com
+	nic-hdl:      XXX007-RIPE # Look, ma, I'm 007! ;)
+	mnt-by:       NICE-GUY-MNT
+	changed:      xxx@somewhere.com 20001016
+	source:       RIPE
 
 Let's assume you need to send an email (for example, to report routing
 problems) to Mr Fool. It means that you need to retrieve the I<e-mail> field
@@ -398,46 +357,43 @@ Let's assume you have the previous text in the C<$text> variable. In order to
 parse the contents of the text into a nice Perl data structure, all you need to
 do is instanciate a parser, with
 
-    use RPSL::Parser;
-    my $parser = new RPSL::Parser;
+        use RPSL::Parser;
+	my $parser = new RPSL::Parser;
 
 And then pass it the contents of the C<$text> variable, and collect the
 resulting data structure back:
 
-    my $data_structure = $parser->parse( $text );
+        my $data_structure = $parser->parse( $text );
 
 It will give you something that will look more or less like this (dumped by
 L<Data::Dumper>):
 
-    $data_strucutre = {
-        __META => {
-            'omit_key' => [4],
-            'comment'  => { 8 => q{Look, ma, I'm 007! ;)} },
-            'order'    => [
-                'person',  'address', 'address', 'address',
-                'address', 'phone',   'fax-no',  'e-mail',
-                'nic-hdl', 'mnt-by',  'changed', 'source'
-            ],
-            'type' => 'person',
-            'data' => {
-                'source'  => 'RIPE',
-                'mnt-by'  => 'NICE-GUY-MNT',
-                'phone'   => '+99-99-999-9999',
-                'nic-hdl' => 'XXX007-RIPE',
-                'fax-no'  => '+99-99-999-9999',
-                'e-mail'  => 'xxx@somewhere.com',
-                'changed' => 'xxx@somewhere.com 20001016',
-                'person'  => 'I. M. A. Fool',
-                'address' => [
-                    'F.A.K.E Corporation',
-                    '226 Nowhere st',
-                    '10DD10 Nevercity',
-                    'Neverland'
-                ]
-            },
-            'key' => 'I. M. A. Fool'
-        },
-    };
+	$data_strucutre = {
+	    'omit_key' => [ 4 ],
+	    'comment'  => { 8 => q{Look, ma, I'm 007! ;)} },
+	    'order'    => [
+		'person', 'address', 'address', 'address', 'address', 'phone',
+		'fax-no', 'e-mail',  'nic-hdl', 'mnt-by',  'changed', 'source'
+	    ],
+	    'type' => 'person',
+	    'data' => {
+		'source'  => 'RIPE',
+		'mnt-by'  => 'NICE-GUY-MNT',
+		'phone'   => '+99-99-999-9999',
+		'nic-hdl' => 'XXX007-RIPE',
+		'fax-no'  => '+99-99-999-9999',
+		'e-mail'  => 'xxx@somewhere.com',
+		'changed' => 'xxx@somewhere.com 20001016',
+		'person'  => 'I. M. A. Fool',
+		'address' => [
+		    'F.A.K.E Corporation',
+		    '226 Nowhere st',
+		    '10DD10 Nevercity',
+		    'Neverland'
+		]
+	    },
+	    'key' => 'I. M. A. Fool'
+	};
 
 In a near future, there will be other objects that will know how to interpret
 this as the specific RPSL object declared, and to write the corresponding RPSL
@@ -447,6 +403,8 @@ representation of a given data structure, simmilar to this one.
 
 RFC2622 L<http://www.ietf.org/rfc/rfc2622.txt>, for the full RPSL specification.
 
+L<Object::Accessor>, for the accessor implementation used in this module.
+
 =head1 AUTHOR
 
 Luis Motta Campos, E<lt>lmc@cpan.orgE<gt>
